@@ -9,7 +9,7 @@ def to_str(value):
         return value.decode('utf-8', 'ignore')
     return value.encode('utf-8', 'ignore')
 
-def notify(title, message='', url='http://localhost:5222', path='/'):
+def notify(title, message='', url='http://localhost:5222', path='/', recipients=[]):
     """
     - **title**: message title (required).
 
@@ -26,20 +26,20 @@ def notify(title, message='', url='http://localhost:5222', path='/'):
     """
     try:
         res = Resource(url)
-        data = dict(title=title, message=message)
+        data = dict(title=title, message=message, recipients=recipients or None)
         page = res.post(path=path, payload=dumps(data), headers={'Content-Type': 'application/json'})
         return loads(page.body)
     except Exception, e:
         return dict(status=1, notify_error=str(e))
 
 
-def quick_notify(title, message='', url='http://localhost:5222', path='/', timeout=0.5):
+def quick_notify(title, message='', url='http://localhost:5222', path='/', recipients=[], timeout=0.5):
     """
     Same as :func:`notifier.notify` but with a timeout
     """
     opener = urllib2.build_opener()
     opener.addheaders = [('Content-Type', 'application/json')]
-    data = dict(title=title, message=message)
+    data = dict(title=title, message=message, recipients=recipients or None)
     socket.setdefaulttimeout(timeout)
     try:
         data = opener.open('%s%s' % (url, path), dumps(data)).read()
@@ -67,24 +67,27 @@ def _main(args=[]):
     parser.usage = '%prog [options] message'
     parser.add_option("-u", "--url", dest="url",
                       default='http://localhost:5222',
-                      help="http host")
+                      help="HTTP Host")
+    parser.add_option("-r", "--recipient", dest="recipients",
+                      action="append", default=[],
+                      help="Recipients. You can have more than one -r")
     parser.add_option("-q", "--quick", dest="quick",
                       action="store_true", default=False,
-                      help="http host")
+                      help="Use quick notifier")
     parser.add_option("-i", "--im", dest="im",
                       action="store_true", default=False,
-                      help="only send on im")
+                      help="Only send on IM")
     parser.add_option("-m", "--minutes", dest="minutes",
                       type="int", default="0",
-                      help="wait X minutes before sending")
+                      help="Wait X minutes before sending")
     parser.add_option("-s", "--seconds", dest="seconds",
                       type="int", default="0",
-                      help="wait X seconds before sending")
+                      help="Wait X seconds before sending")
     parser.add_option("-c", "--cook", dest="cook", metavar="INGREDIENT",
-                      help="send notification for cooking. Valid ingredients are: %s" % cook_str)
+                      help="Send notification for cooking. Valid ingredients are: %s" % cook_str)
     parser.add_option("-v", "--verbose", dest="verbose",
                       action="count", default=0,
-                      help="more output")
+                      help="More output")
     if args:
         options, args = parser.parse_args(args)
     else:
@@ -124,7 +127,8 @@ def _main(args=[]):
     log.debug('Sending notification...')
     results = meth(to_str(' '.join(args)),
                    url=options.url.strip('/'),
-                   path=options.im and '/gtalk' or '/'
+                   path=options.im and '/gtalk' or '/',
+                   recipients=options.recipients,
                   )
 
     if results.get('status') == 0:
