@@ -45,40 +45,42 @@ class Notifier(object):
             self.gtalk('Notifier started')
 
     @status
-    def gtalk(self, title, message, recipients):
-        cl=xmpp.Client(self.jid.getDomain(),debug=[])
-        cl.connect(('talk.google.com', 5222))
-        cl.auth(self.jid.getNode(), self.passwd)
-        if message:
-            body = '%s\n\n%s' % (to_str(title), to_str(message))
-        else:
-            body = title
-        for recipient in recipients:
-            cl.send(xmpp.Message(recipient, body))
-        cl.disconnect()
+    def gtalk(self, title, message, recipients, testing=False):
+        if not testing:
+            cl=xmpp.Client(self.jid.getDomain(),debug=[])
+            cl.connect(('talk.google.com', 5222))
+            cl.auth(self.jid.getNode(), self.passwd)
+            if message:
+                body = '%s\n\n%s' % (to_str(title), to_str(message))
+            else:
+                body = title
+            for recipient in recipients:
+                cl.send(xmpp.Message(recipient, body))
+            cl.disconnect()
 
     @status
-    def gmail(self, title, message, recipients):
-        msg = MIMEMultipart()
-        msg['From'] = self.gid
-        msg['To'] = ','.join(self.recipients)
-        msg['Subject'] = title
-        msg.attach(MIMEText(message))
-        msg = msg.as_string()
+    def gmail(self, title, message, recipients, testing=False):
+        if not testing:
+            msg = MIMEMultipart()
+            msg['From'] = self.gid
+            msg['To'] = ','.join(self.recipients)
+            msg['Subject'] = title
+            msg.attach(MIMEText(message))
+            msg = msg.as_string()
 
-        cl = smtplib.SMTP('smtp.gmail.com', 587)
-        cl.ehlo()
-        cl.starttls()
-        cl.ehlo()
-        cl.login(self.gid, self.passwd)
-        for recipient in recipients:
-            cl.sendmail(self.gid, recipient, msg)
-        cl.close()
+            cl = smtplib.SMTP('smtp.gmail.com', 587)
+            cl.ehlo()
+            cl.starttls()
+            cl.ehlo()
+            cl.login(self.gid, self.passwd)
+            for recipient in recipients:
+                cl.sendmail(self.gid, recipient, msg)
+            cl.close()
 
     @status
-    def send(self, title, message='', recipients=None):
-        results = self.gtalk(title, message, recipients)
-        results.update(self.gmail(title, message, recipients))
+    def send(self, title, message, recipients, testing=False):
+        results = self.gtalk(title, message, recipients, testing=testing)
+        results.update(self.gmail(title, message, recipients, testing=testing))
         return results
 
     def __call__(self, environ, start_response):
@@ -86,6 +88,7 @@ class Notifier(object):
         req = Request(environ)
         resp = Response()
         path_info = req.path_info
+        testing = 'paste.testing' in req.environ
         results = dict(status=1)
         if req.method == 'POST':
             try:
@@ -96,19 +99,23 @@ class Notifier(object):
                 if 'title' in data:
                     title = to_str(data.get('title', ''))
                     message = to_str(data.get('message', ''))
-                    recipients = data.get('recipients', self.recipients)
+                    recipients = data.get('recipients', None)
                     if not isinstance(recipients, list):
                         recipients = self.recipients
+                    elif not recipients:
+                        recipients = self.recipients
                     recipients = set(recipients)
                     if path_info == '/':
-                        data = self.send(title, message, recipients)
+                        data = self.send(title, message, recipients, testing=testing)
                     elif path_info == '/gtalk':
-                        data = self.gtalk(title, message, recipients)
+                        data = self.gtalk(title, message, recipients, testing=testing)
                     elif path_info == '/gmail':
-                        data = self.gmail(title, message, recipients)
+                        data = self.gmail(title, message, recipients, testing=testing)
                     else:
                         data = {}
                     results.update(data, recipients=list(recipients))
+                else:
+                    results['error'] = 'No title found in JSON data'
             results['time'] = time.time() - t
             resp.content_type='application/json'
             resp.body = dumps(results)
